[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
79/91: gnu: python-pytest-trio: Move to pyproject-build-system.
From: |
guix-commits |
Subject: |
79/91: gnu: python-pytest-trio: Move to pyproject-build-system. |
Date: |
Thu, 23 May 2024 17:17:38 -0400 (EDT) |
ngz pushed a commit to branch python-team
in repository guix.
commit 00eb9a1a01120efeb407c9960028d947c1ca970d
Author: Nicolas Graves <ngraves@ngraves.fr>
AuthorDate: Fri May 10 00:54:15 2024 +0200
gnu: python-pytest-trio: Move to pyproject-build-system.
* gnu/packages/python-check.scm (python-pytest-trio):
[build-system]: Move to pyproject-build-system.
[arguments]: Move from <#:phases> to <#test-flags>.
Change-Id: I7653110fc299d0757f7e01c2c1c29d599cb206bf
Signed-off-by: Nicolas Goaziou <mail@nicolasgoaziou.fr>
---
gnu/packages/python-check.scm | 25 ++++++++++---------------
1 file changed, 10 insertions(+), 15 deletions(-)
diff --git a/gnu/packages/python-check.scm b/gnu/packages/python-check.scm
index ccda2042fb..46c8b3414e 100644
--- a/gnu/packages/python-check.scm
+++ b/gnu/packages/python-check.scm
@@ -1186,22 +1186,17 @@ simpler.")
(uri (pypi-uri "pytest-trio" version))
(sha256
(base32 "0c8cqf9by2884riksrqymqfp2g1d2d798a2zalcw9hmf34c786y0"))))
- (build-system python-build-system)
+ (build-system pyproject-build-system)
(arguments
- `(#:phases
- (modify-phases %standard-phases
- (replace 'check
- (lambda* (#:key tests? inputs outputs #:allow-other-keys)
- (when tests?
- (add-installed-pythonpath inputs outputs)
- (invoke "pytest" "-W" "error" "-ra" "-v" "--pyargs"
- "pytest_trio" "--verbose" "--cov" "-k"
- (string-append
- ;; Needs network
- "not test_async_yield_fixture_with_nursery"
- " and not test_try"
- ;; No keyboard interrupt in our build environment.
- " and not test_actual_test"))))))))
+ (list
+ #:test-flags '(list "-W" "error" "-ra" "-v" "--pyargs"
+ "pytest_trio" "--verbose" "--cov" "-k"
+ (string-append
+ ;; Needs network
+ "not test_async_yield_fixture_with_nursery"
+ " and not test_try"
+ ;; No keyboard interrupt in our build environment.
+ " and not test_actual_test"))))
(native-inputs
(list python-hypothesis python-pytest python-pytest-cov))
(propagated-inputs
- 41/91: gnu: python-parse-type: Move to pyproject-build-system., (continued)
- 41/91: gnu: python-parse-type: Move to pyproject-build-system., guix-commits, 2024/05/23
- 21/91: gnu: conda: Move to pyproject-build-system., guix-commits, 2024/05/23
- 46/91: gnu: abjad-ext-rmakers: Update to 3.19., guix-commits, 2024/05/23
- 50/91: gnu: python-cairosvg: Move to pyproject-build-system., guix-commits, 2024/05/23
- 56/91: gnu: python-jaraco-test: Move to pyproject-build-system., guix-commits, 2024/05/23
- 66/91: gnu: python-flake8-isort: Move to pyproject-build-system., guix-commits, 2024/05/23
- 63/91: gnu: python-autoflake: Update to 2.3.1., guix-commits, 2024/05/23
- 70/91: gnu: Add python-sphinx-autodoc-typehints-5., guix-commits, 2024/05/23
- 69/91: gnu: python-cmd2: Move to pyproject-build-system., guix-commits, 2024/05/23
- 74/91: gnu: python-typeguard-4: Ignore failing tests., guix-commits, 2024/05/23
- 79/91: gnu: python-pytest-trio: Move to pyproject-build-system.,
guix-commits <=
- 76/91: gnu: python-funsor: Ignore flaky test., guix-commits, 2024/05/23
- 83/91: gnu: python-multidict: Move to pyproject-build-system., guix-commits, 2024/05/23
- 90/91: gnu: python-notebook: Add python-jupyter-server to native inputs., guix-commits, 2024/05/23
- 88/91: gnu: python-qemu-qmp: Move to pyproject-build-system., guix-commits, 2024/05/23
- 49/91: gnu: python-pytest-toolbox: Move to pyproject-build-system., guix-commits, 2024/05/23
- 52/91: gnu: python-jaraco-classes: Move to pyproject-build-system., guix-commits, 2024/05/23
- 34/91: gnu: gunicorn: Update to 21.2.0., guix-commits, 2024/05/23
- 55/91: gnu: python-jaraco-packaging: Move to pyproject-build-system., guix-commits, 2024/05/23
- 58/91: gnu: Add ghc-xcb-types., guix-commits, 2024/05/23
- 67/91: gnu: python-xmltodict: Move to pyproject-build-system., guix-commits, 2024/05/23